@@ -4,7 +4,7 @@ from typing import Optional
 
 from dataclasses_json import dataclass_json
 
-from telescope_sdk.common import TelescopeBaseType, Location
+from telescope_sdk.common import Location, IngestedDataType
 
 
 class CompanyType(Enum):
@@ -29,7 +29,7 @@ class CompanySizeRange:
 
 @dataclass_json
 @dataclass
-class Company(TelescopeBaseType):
+class Company(IngestedDataType):
     name: str
     linkedin_internal_id: str
     pdl_id: Optional[str] = None
@@ -45,9 +45,9 @@ class Company(TelescopeBaseType):
     industry: Optional[str] = None
     categories: Optional[list[str]] = None
     specialties: Optional[list[str]] = None
-    company_type: Optional[CompanyType] = None
-    company_size_range: Optional[CompanySizeRange] = None
+    company_type: Optional['CompanyType'] = None
+    company_size_range: Optional['CompanySizeRange'] = None
     company_size_on_linkedin: Optional[int] = None
     founded_year: Optional[int] = None
     hq: Optional[Location] = None
-    locations: Optional[list[Location]] = None
+    locations: Optional[list['Location']] = None
