@@ -1,12 +1,10 @@
-from __future__ import annotations
-
 import uuid
 from dataclasses import dataclass
 from typing import Optional
 
 from dataclasses_json import dataclass_json
 
-from telescope_sdk.common import Location, TelescopeBaseType, Source
+from telescope_sdk.common import Location, IngestedDataType, Source
 from telescope_sdk.utils import (
     convert_date_string_to_datetime_string,
     get_current_datetime_aws_format,
@@ -20,11 +18,11 @@ class ExperienceCompany:
     name: Optional[str] = None
     linkedin_internal_id: Optional[str] = None
     linkedin_url: Optional[str] = None
-    location: Optional[Location] = None
+    location: Optional['Location'] = None
     website: Optional[str] = None
 
     @staticmethod
-    def from_pdl(pdl_input: dict[str, any]) -> Optional[ExperienceCompany]:
+    def from_pdl(pdl_input: dict[str, any]) -> Optional['ExperienceCompany']:
         location = pdl_input.get('location')
         return ExperienceCompany(
             name=pdl_input.get('name'),
@@ -38,7 +36,7 @@ class ExperienceCompany:
 @dataclass_json
 @dataclass
 class Experience:
-    company: Optional[ExperienceCompany] = None
+    company: Optional['ExperienceCompany'] = None
     start_datetime: Optional[str] = None
     end_datetime: Optional[str] = None
     is_primary: Optional[bool] = None
@@ -46,7 +44,7 @@ class Experience:
     job_title_levels: Optional[list[str]] = None
 
     @staticmethod
-    def from_pdl(pdl_input: dict[str, any]) -> Optional[Experience]:
+    def from_pdl(pdl_input: dict[str, any]) -> Optional['Experience']:
         title = pdl_input.get('title', {}) or {}
         company = pdl_input.get('company')
         start_date = pdl_input.get('start_date')
@@ -71,7 +69,7 @@ class Degree:
 @dataclass_json
 @dataclass
 class Education:
-    degree: Optional[Degree] = None
+    degree: Optional['Degree'] = None
     institution_logo_url: Optional[str] = None
     institution_name: Optional[str] = None
     institution_linkedin_url: Optional[str] = None
@@ -79,7 +77,7 @@ class Education:
     end_datetime: Optional[str] = None
 
     @staticmethod
-    def from_pdl(pdl_input: dict[str, any]) -> Optional[Education]:
+    def from_pdl(pdl_input: dict[str, any]) -> Optional['Education']:
         school = pdl_input.get('school', {})
         start_date = pdl_input.get('start_date')
         end_date = pdl_input.get('end_date')
@@ -105,7 +103,7 @@ class Language:
 
 @dataclass_json
 @dataclass
-class Person(TelescopeBaseType):
+class Person(IngestedDataType):
     first_name: str
     last_name: str
     middle_name: Optional[str] = None
@@ -130,16 +128,16 @@ class Person(TelescopeBaseType):
     job_last_updated: Optional[str] = None
     interests: Optional[list[str]] = None
     skills: Optional[list[str]] = None
-    experience: Optional[list[Experience]] = None
-    education: Optional[list[Education]] = None
-    languages: Optional[list[Language]] = None
-    location: Optional[Location] = None
+    experience: Optional[list['Experience']] = None
+    education: Optional[list['Education']] = None
+    languages: Optional[list['Language']] = None
+    location: Optional['Location'] = None
     tags: Optional[list[str]] = None
     uploaded_by_user_id: Optional[str] = None
     last_enriched_at: Optional[str] = None
 
     @staticmethod
-    def from_pdl(pdl_input: dict[str, any]) -> Optional[Person]:
+    def from_pdl(pdl_input: dict[str, any]) -> Optional['Person']:
         first_name = pdl_input.get('first_name')
         last_name = pdl_input.get('last_name')
         if not first_name or not last_name:
@@ -181,7 +179,7 @@ class Person(TelescopeBaseType):
             skills=pdl_input.get('skills'),
             experience=[Experience.from_pdl(experience) for experience in pdl_input.get('experience', [])],
             education=[Education.from_pdl(education) for education in pdl_input.get('education', [])],
-            languages=[Language.from_dict(language) for language in pdl_input.get('languages', [])],
+            languages=Language.schema().load(pdl_input.get('languages', []), many=True),
             location=Location(
                 line_1=pdl_input.get('location_street_address'),
                 line_2=pdl_input.get('location_address_line_2'),
